window.Gleam.initSearch([{"doc":"mockth","title":"mockth","content":"# mockth\n\n[![Package Version](https://img.shields.io/hexpm/v/mockth)](https://hex.pm/packages/mockth)\n[![Hex Docs](https://img.shields.io/badge/hex-docs-ffaff3)](https://hexdocs.pm/mockth/)\n\nGleam modules mocking library. This is simple wrapper around Erlang [meck](https://github.com/eproxus/meck) library.\n\n```sh\ngleam add mockth\n```\n\n## Usage\n\nIt provides a simple API to mock Gleam modules and functions. All you need to use `mockth.expect` function to mock any external function with your own implementation.\n\n```gleam\nimport gleeunit\nimport gleeunit/should\nimport gleam/function\nimport mockth\n\npub fn main() {\n  gleeunit.main()\n}\n\npub fn expect1_test() {\n  let assert Ok(_) =\n    mockth.expect1(&quot;gleam/function&quot;, &quot;identity&quot;, fn(_args) { &quot;hello&quot; })\n\n  mockth.validate(&quot;gleam/function&quot;)\n  |&gt; should.equal(True)\n\n  mockth.mocked()\n  |&gt; should.equal([&quot;gleam/function&quot;])\n\n  function.identity(&quot;world&quot;)\n  |&gt; should.equal(&quot;hello&quot;)\n\n  mockth.unload_all()\n}\n```\n\nDon&#39;t forget to unload all mocks after each test case.\n\nFurther documentation can be found at &lt;https://hexdocs.pm/mockth&gt;.\n\n## Development\n\n```sh\ngleam run   # Run the project\ngleam test  # Run the tests\ngleam shell # Run an Erlang shell\n```\n","url":"index.html"},{"doc":"mockth","title":"expect1","content":"pub fn expect1(\n  module: String,\n  function: String,\n  fun: fn(a) -&gt; b,\n) -&gt; Result(Bool, String)\n Mock a function with 1 argument\n\n \n pub fn expect1_test() {\n  let assert Ok(_) =\n    mockth.expect1(&quot;gleam/function&quot;, &quot;identity&quot;, fn(_args) { &quot;hello&quot; })\n\n  mockth.validate(&quot;gleam/function&quot;)\n  |&gt; should.equal(True)\n\n  mockth.mocked()\n  |&gt; should.equal([&quot;gleam/function&quot;])\n\n  function.identity(&quot;world&quot;)\n  |&gt; should.equal(&quot;hello&quot;)\n }\nSynonyms:\nmockth.expect1\nmockth expect1","url":"mockth.html#expect1"},{"doc":"mockth","title":"expect2","content":"pub fn expect2(\n  module: String,\n  function: String,\n  fun: fn(a, b) -&gt; c,\n) -&gt; Result(Bool, String)\n Mock a function with 2 arguments\nSynonyms:\nmockth.expect2\nmockth expect2","url":"mockth.html#expect2"},{"doc":"mockth","title":"expect3","content":"pub fn expect3(\n  module: String,\n  function: String,\n  fun: fn(a, b, c) -&gt; d,\n) -&gt; Result(Bool, String)\n Mock a function with 3 arguments\nSynonyms:\nmockth.expect3\nmockth expect3","url":"mockth.html#expect3"},{"doc":"mockth","title":"expect4","content":"pub fn expect4(\n  module: String,\n  function: String,\n  fun: fn(a, b, c, d) -&gt; e,\n) -&gt; Result(Bool, String)\n Mock a function with 4 arguments\nSynonyms:\nmockth.expect4\nmockth expect4","url":"mockth.html#expect4"},{"doc":"mockth","title":"expect5","content":"pub fn expect5(\n  module: String,\n  function: String,\n  fun: fn(a, b, c, d, e) -&gt; f,\n) -&gt; Result(Bool, String)\n Mock a function with 5 arguments\nSynonyms:\nmockth.expect5\nmockth expect5","url":"mockth.html#expect5"},{"doc":"mockth","title":"mocked","content":"pub fn mocked() -&gt; List(String)\n Returns the currently mocked modules.\nSynonyms:\nmockth.mocked\nmockth mocked","url":"mockth.html#mocked"},{"doc":"mockth","title":"unload","content":"pub fn unload(module: String) -&gt; Result(Bool, String)\n Unload a mocked module or a list of mocked modules.\n This will purge and delete the module(s) from the Erlang virtual machine. If the mocked module(s) replaced an existing module, this module will still be in the Erlang load path and can be loaded manually or when called.\nSynonyms:\nmockth.unload\nmockth unload","url":"mockth.html#unload"},{"doc":"mockth","title":"unload_all","content":"pub fn unload_all() -&gt; List(String)\n The function returns the list of mocked modules that were unloaded in the process.\n Unloads all mocked modules from memory.\nSynonyms:\nmockth.unload_all\nmockth unload_all","url":"mockth.html#unload_all"},{"doc":"mockth","title":"validate","content":"pub fn validate(module: String) -&gt; Bool\n Validate the state of the mock module(s).\n Validation can detect:\n - When a function was called with the wrong argument types (function_clause)\n - When an exception was thrown\n - When an exception was thrown and expected (via meck:exception/2), which still results in true being returned\n\n Validation cannot detect:\n - When you didn&#39;t call a function\n - When you called a function with the wrong number of arguments (undef)\n - When you called an undefined function (undef)\nSynonyms:\nmockth.validate\nmockth validate","url":"mockth.html#validate"},{"doc":"mockth","title":"mockth","content":"","url":"mockth.html"}]);